@@ -15,8 +15,8 @@
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along with
- *  this program; if not, write to the Free Software Foundation, Inc., 675 Mass
- *  Ave, Cambridge, MA 02139, USA.
+ *  this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. 
  *
  */
 
@@ -25,8 +25,8 @@
 #define DEVICE_H_
 
 void nwipe_device_identify( nwipe_context_t* c );  /* Get hardware information about the device.  */
-//int  nwipe_device_scan( char*** device_names );    /* Find devices that we can wipe.              */
-int  nwipe_device_scan( nwipe_context_t** c );    /* Find devices that we can wipe.              */
+int nwipe_device_scan( nwipe_context_t*** c );     /* Find devices that we can wipe.              */
+int nwipe_device_get( nwipe_context_t*** c, char **devnamelist, int ndevnames ); /* Get info about devices to wipe */
 
 #endif /* DEVICE_H_ */
 
