@@ -15,8 +15,8 @@
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along with
- *  this program; if not, write to the Free Software Foundation, Inc., 675 Mass
- *  Ave, Cambridge, MA 02139, USA.
+ *  this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. 
  *
  */
 
@@ -123,7 +123,7 @@ const char* options_title = " Options ";
 const char* stats_title = " Statistics ";
 
 /* Footer labels. */
-const char* nwipe_buttons1 = " P=PRNG M=Method V=Verify R=Rounds, J=Up K=Down Space=Select, F10=Start, ctrl-c=Quit ";
+const char* nwipe_buttons1 = " P=PRNG M=Method V=Verify R=Rounds B=Blanking-pass, J=Up K=Down Space=Select, F10=Start, ctrl-c=Quit ";
 const char* nwipe_buttons2 = " J=Up K=Down Space=Select";
 const char* nwipe_buttons3 = " B=Blank screen, ctrl-c=Quit";
 
@@ -308,10 +308,6 @@ void nwipe_gui_init( void )
 	box( main_window, 0, 0 );
 
 	/* Refresh the screen. */
-	while ( log_writing_screen )
-	{
-		sleep(1);
-	}
 	wrefresh( stdscr );
 	wrefresh( header_window );
 	wrefresh( footer_window );
@@ -446,28 +442,35 @@ void nwipe_gui_select( int count, nwipe_context_t** c )
 			{
 				case NWIPE_SELECT_TRUE:
 
-					/* Print a selected element. */
-					wprintw( main_window, " [wipe] %s (%lld bytes)", c[i+offset]->label,
+					wprintw( main_window, " [wipe] %i. %s - %s (%lld bytes)", (i + offset + 1),
+										c[i+offset]->device_name,
+										c[i+offset]->label,
 										c[i+offset]->device_size );
 					break;
 
 				case NWIPE_SELECT_FALSE:
 					/* Print an element that is not selected. */
-					wprintw( main_window, " [    ] %s (%lld bytes)", c[i+offset]->label,
+					wprintw( main_window, " [    ] %i. %s - %s (%lld bytes)", (i + offset +1),
+										c[i+offset]->device_name,
+										c[i+offset]->label,
 										c[i+offset]->device_size );
 					break;
 
 				case NWIPE_SELECT_TRUE_PARENT:
 
 					/* This element will be wiped when its parent is wiped. */
-					wprintw( main_window, " [****] %s (%lld bytes)", c[i+offset]->label,
+					wprintw( main_window, " [****] %i. %s - %s (%lld bytes)", (i + offset +1),
+										c[i+offset]->device_name,
+										c[i+offset]->label,
 										c[i+offset]->device_size );
 					break;
 
 				case NWIPE_SELECT_FALSE_CHILD:
 
 					/* We can't wipe this element because it has a child that is being wiped. */
-					wprintw( main_window, " [----] %s (%lld bytes)", c[i+offset]->label,
+					wprintw( main_window, " [----] %i. %s - %s (%lld bytes)", (i + offset +1),
+										c[i+offset]->device_name,
+										c[i+offset]->label,
 										c[i+offset]->device_size );
 					break;
 
@@ -730,9 +733,16 @@ void nwipe_gui_select( int count, nwipe_context_t** c )
 				nwipe_gui_verify();
 				break;
 
+			case 'b':
+			case 'B':
+
+				/* Run the noblank dialog. */
+				nwipe_gui_noblank();
+				break;
+
 		} /* keystroke switch */
 
-	} while( keystroke != KEY_F(10) );
+	} while( keystroke != KEY_F(10) && keystroke != ERR );
 
 	/* Clear the main window. */
 	werase( main_window );
@@ -794,8 +804,13 @@ void nwipe_gui_options( void )
 
 
 	mvwprintw( options_window, NWIPE_GUI_OPTIONS_ROUNDS_Y,  NWIPE_GUI_OPTIONS_ROUNDS_X,  "Rounds:  " );
-	wprintw( options_window, "%i", nwipe_options.rounds );
-
+	if ( nwipe_options.noblank )
+	{
+		wprintw( options_window, "%i (no final blanking pass)", nwipe_options.rounds);
+	} else
+	{
+		wprintw( options_window, "%i (plus blanking pass)", nwipe_options.rounds);
+	}
 
 	/* Add a border. */
 	box( options_window, 0, 0 );
@@ -919,7 +934,7 @@ void nwipe_gui_rounds( void )
 		/* Hide the cursor. */
 		curs_set( 0 );
 
-	} while( keystroke != 10 );
+	} while( keystroke != 10 && keystroke != ERR );
 
 	if( focus > 0 )
 	{
@@ -971,7 +986,7 @@ void nwipe_gui_prng( void )
 	if( nwipe_options.prng == &nwipe_isaac   ) { focus = 1; }
 
 
-	while( 1 )
+	while( keystroke != ERR )
 	{
 		/* Clear the main window. */
 		werase( main_window );
@@ -1100,7 +1115,7 @@ void nwipe_gui_verify( void )
 	nwipe_gui_title( footer_window, nwipe_buttons2 );
 	wrefresh( footer_window );
 
-	while( 1 )
+	while( keystroke != ERR )
 	{
 		/* Clear the main window. */
 		werase( main_window );
@@ -1184,7 +1199,8 @@ void nwipe_gui_verify( void )
 			case ' ':
 			case 10:
 
-				if( focus >= 0 && focus < count ){ nwipe_options.verify = focus; }
+				if( focus >= 0 && focus < count ) { nwipe_options.verify = focus; }
+				if( nwipe_options.verify != NWIPE_VERIFY_NONE ) { nwipe_options.noblank = 0; }
 				return;
 
 			case KEY_BACKSPACE:
@@ -1199,6 +1215,126 @@ void nwipe_gui_verify( void )
 } /* nwipe_gui_verify */
 
 
+void nwipe_gui_noblank( void )
+{
+/**
+ * Allows the user to change the verification option.
+ *
+ * @modifies  nwipe_options.noblank
+ * @modifies  main_window
+ *
+ */
+
+	/* The number of options available. */
+	const int count = 2;
+
+	/* The first tabstop. */
+	const int tab1 = 2;
+
+	/* The second tabstop. */
+	const int tab2 = 40;
+
+	/* Set the initial focus. */
+	int focus = nwipe_options.noblank;
+
+	/* The current working row. */
+	int yy;
+
+	/* Input buffer. */
+	int keystroke;
+
+	/* Update the footer window. */
+	werase( footer_window );
+	nwipe_gui_title( footer_window, nwipe_buttons2 );
+	wrefresh( footer_window );
+
+	while( keystroke != ERR )
+	{
+		/* Clear the main window. */
+		werase( main_window );
+
+		/* Initialize the working row. */
+		yy = 2;
+
+		/* Print the options. */
+		mvwprintw( main_window, yy++, tab1, "  Perform a final blanking pass       " );
+		mvwprintw( main_window, yy++, tab1, "  Do not perform final blanking pass  " );
+		mvwprintw( main_window, yy++, tab1, "                                      " );
+
+		/* Print the cursor. */
+		mvwaddch( main_window, 2 + focus, tab1, ACS_RARROW );
+
+
+		switch( focus )
+		{
+			case 0:
+
+				mvwprintw( main_window, 2, tab2, "syslinux.cfg:  nuke=\"nwipe\"" );
+
+				/*                                 0         1         2         3         4         5         6         7        8  */
+				mvwprintw( main_window, yy++, tab1, "Perform a final blanking pass after the wipe, leaving disk with only zeros. " );
+				mvwprintw( main_window, yy++, tab1, "                                                                            " );
+				break;
+
+			case 1:
+
+				mvwprintw( main_window, 2, tab2, "syslinux.cfg:  nuke=\"nwipe -b\"" );
+
+				/*                                 0         1         2         3         4         5         6         7        8  */
+				mvwprintw( main_window, yy++, tab1, "Do not perform a final blanking pass. Leave data as per final wiping pass.  " );
+				mvwprintw( main_window, yy++, tab1, "Any verification options will be ignored. Not compatible with Quick Erase.  " );
+				break;
+
+		} /* switch */
+
+		/* Add a border. */
+		box( main_window, 0, 0 );
+
+		/* Add a title. */
+		nwipe_gui_title( main_window, " Final Blanking Pass " );
+
+		/* Refresh the window. */
+		wrefresh( main_window );
+
+		/* Get a keystroke. */
+		keystroke = getch();
+
+		switch( keystroke )
+		{
+			case KEY_DOWN:
+			case 'j':
+			case 'J':
+
+				if( focus < count -1 ) { focus += 1; } 
+				break;
+
+			case KEY_UP:
+			case 'k':
+			case 'K':
+
+				if( focus > 0 ) { focus -= 1; } 
+				break;
+
+			case KEY_ENTER:
+			case ' ':
+			case 10:
+
+				if( focus >= 0 && focus < count ){ nwipe_options.noblank = focus; }
+				if ( nwipe_options.noblank ) { nwipe_options.verify = NWIPE_VERIFY_NONE; }
+				return;
+
+			case KEY_BACKSPACE:
+			case KEY_BREAK:
+
+				return;
+
+		} /* switch */
+		
+	} /* while */
+
+} /* nwipe_gui_noblank */
+
+
 void nwipe_gui_method( void )
 {
 /**
@@ -1369,7 +1505,7 @@ void nwipe_gui_method( void )
 
 		} /* switch */
 
-	} while( keystroke != KEY_ENTER && keystroke != ' ' && keystroke != 10 );
+	} while( keystroke != KEY_ENTER && keystroke != ' ' && keystroke != 10 && keystroke != ERR );
 
 
         switch( focus )
@@ -1553,10 +1689,6 @@ void *nwipe_gui_status( void *ptr )
 
 	/* Add text to footer window */
 	nwipe_gui_title( footer_window, nwipe_buttons3 );
-	while ( log_writing_screen )
-	{
-		sleep(1);
-	}
 	wrefresh( footer_window );
 
 	while ( nwipe_active ) {
@@ -1665,12 +1797,11 @@ void *nwipe_gui_status( void *ptr )
 		if ( nwipe_gui_blank == 0 )
 		{
 
+			nwipe_active = 0; // Number of active wipe threads
 			/* Enumerate all contexts to compute statistics. */
 			for( i = 0 ; i < count ; i++ )
 			{
-			
 				/* Check whether the child process is still running the wipe. */
-				nwipe_active = 0;
 				if( c[i]->thread > 0 )
 				{
 					/* Increment the child counter. */
@@ -1799,10 +1930,6 @@ void *nwipe_gui_status( void *ptr )
 			box( main_window, 0, 0 );
 
 			/* Refresh the main window. */
-			while ( log_writing_screen )
-			{
-				sleep(1);
-			}
 			wrefresh( main_window );
 
 			/* Update the load average field. */
@@ -1868,14 +1995,37 @@ void *nwipe_gui_status( void *ptr )
 			mvwprintw( stats_window, 0, ( NWIPE_GUI_STATS_W - strlen( stats_title ) ) /2, "%s", stats_title );
 
 			/* Refresh the stats window. */
-			while ( log_writing_screen )
-			{
-				sleep(1);
-			}
 			wrefresh( stats_window );
 
 		} // end blank screen if
 
+        	if (nwipe_options.logfile[0] == '\0') {
+        	
+        		// Logging to STDOUT. Flush log.
+
+			def_prog_mode();                /* Save the tty modes             */
+			endwin();                       /* End curses mode temporarily    */
+			
+			/* Flush stdout and disable buffering, otherwise output missed new lines. */
+			fflush(stdout);
+			setbuf(stdout, NULL);
+			
+			pthread_mutex_lock( &mutex1 );
+			
+			for (i=0; i < log_current_element; i++)
+			{
+				printf("%s\n", log_lines[i]);
+			}
+			log_current_element = 0;
+
+			pthread_mutex_unlock( &mutex1 );
+			
+			reset_prog_mode();              /* Return to the previous tty mode*/
+							/* stored by def_prog_mode()      */
+			refresh();                      /* Do refresh() to restore the    */
+							/* Screen contents                */
+		}
+
 		/* Test for a thread cancellation request */
 		pthread_testcancel();
 
