@@ -147,7 +147,14 @@ void nwipe_log( nwipe_log_t level, const char* format, ... )
 
 	if (nwipe_options.logfile[0] == '\0')
 	{
-		log_current_element++;
+		if (nwipe_options.nogui)
+		{
+			printf( "%s\n", log_lines[log_current_element] );
+		}
+		else
+		{
+			log_current_element++;
+		}
 	} else
 	{
 		/* Open the log file for appending. */
