@@ -15,8 +15,8 @@
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along with
- *  this program; if not, write to the Free Software Foundation, Inc., 675 Mass
- *  Ave, Cambridge, MA 02139, USA.
+ *  this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. 
  */
 
 
@@ -590,12 +590,17 @@ int nwipe_runmethod( nwipe_context_t* c, nwipe_pattern_t* patterns )
 	c->round_size = c->round_count * c->pass_size;
 	
 	/* The final pass is always a zero fill, except ops2 which is random. */
-	c->round_size += c->device_size;
+	/* Do not add if there is no blanking pass.                           */
+	if ( nwipe_options.noblank == 0 )
+	{
+		c->round_size += c->device_size;
+	}
 
 	/* Set the round total count down */
 	c->result = c->round_size;
 
-	if( nwipe_options.verify == NWIPE_VERIFY_LAST || nwipe_options.verify == NWIPE_VERIFY_ALL )
+	if((nwipe_options.verify == NWIPE_VERIFY_LAST || nwipe_options.verify == NWIPE_VERIFY_ALL)
+		&& nwipe_options.noblank == 0 )
 	{
 		/* We must read back the last pass to verify it. */
 		c->round_size += c->device_size;
@@ -786,7 +791,7 @@ int nwipe_runmethod( nwipe_context_t* c, nwipe_pattern_t* patterns )
 	} /* final ops2 */
 
 
-	else
+	else if (nwipe_options.noblank == 0)
 	{
 		/* Tell the user that we are on the final pass. */
 		c->pass_type = NWIPE_PASS_FINAL_BLANK;
