@@ -78,6 +78,12 @@ int nwipe_options_parse( int argc, char** argv )
 		/* Whether to blank the disk after wiping. */
 		{ "noblank", no_argument, 0, 0 },
 
+		/* Whether to exit after wiping or wait for a keypress. */
+		{ "nowait", no_argument, 0, 0 },
+
+		/* Whether to exit after wiping or wait for a keypress. */
+		{ "nogui", no_argument, 0, 0 },
+
 		/* A flag to indicate whether the devices whould be opened in sync mode. */
 		{ "sync", no_argument, 0, 0 },
 
@@ -107,6 +113,8 @@ int nwipe_options_parse( int argc, char** argv )
 	nwipe_options.prng     = &nwipe_twister;
 	nwipe_options.rounds   = 1;
 	nwipe_options.noblank  = 0;
+	nwipe_options.nowait   = 0;
+	nwipe_options.nogui    = 0;
 	nwipe_options.sync     = 0;
 	nwipe_options.verify   = NWIPE_VERIFY_LAST;
 	memset( nwipe_options.logfile, '\0', sizeof(nwipe_options.logfile) );
@@ -137,6 +145,19 @@ int nwipe_options_parse( int argc, char** argv )
 					break;
 				}
 
+				if( strcmp( nwipe_options_long[i].name, "nowait" ) == 0 )
+				{
+					nwipe_options.nowait = 1;
+					break;
+				}
+
+				if( strcmp( nwipe_options_long[i].name, "nogui" ) == 0 )
+				{
+					nwipe_options.nogui = 1;
+					nwipe_options.nowait = 1;
+					break;
+				}
+
 				if( strcmp( nwipe_options_long[i].name, "sync" ) == 0 )
 				{
 					nwipe_options.sync = 1;
@@ -306,6 +327,16 @@ void nwipe_options_log( void )
 		nwipe_log( NWIPE_LOG_NOTICE, "  do not perform a final blank pass" );
 	}
 
+	if( nwipe_options.nowait )
+	{
+		nwipe_log( NWIPE_LOG_NOTICE, "  do not wait for a key before exiting" );
+	}
+
+	if( nwipe_options.nogui )
+	{
+		nwipe_log( NWIPE_LOG_NOTICE, "  do not show GUI interface" );
+	}
+
 	nwipe_log( NWIPE_LOG_NOTICE, "  banner   = %s", nwipe_options.banner );
 	nwipe_log( NWIPE_LOG_NOTICE, "  method   = %s", nwipe_method_label( nwipe_options.method ) );
 	nwipe_log( NWIPE_LOG_NOTICE, "  rounds   = %i", nwipe_options.rounds );
@@ -339,11 +370,13 @@ void nwipe_options_log( void )
 void 
 display_help()
 {
-  printf("Usage: %s [options]\n", program_name);
+  printf("Usage: %s [options] [device1] [device2] ...\n", program_name);
   printf("Options:\n"                    );
   puts("  -V, --version           Prints the version number");
   puts("  -h, --help              Prints this help");
-  puts("      --autonuke          Select all devices and start wiping immediately");
+  puts("      --autonuke          If no devices have been specified on the command line, starts wiping all");
+  puts("                          devices immediately. If devices have been specified, starts wiping only");
+  puts("                          those specified devices immediately.");
   puts("      --sync              Open devices in sync mode");
   puts("      --verify=TYPE       Whether to perform verification of erasure (default: last)");
   puts("                          off   - Do not verify");
@@ -360,6 +393,9 @@ display_help()
   puts("  -p, --prng=METHOD       PRNG option (mersenne|twister|isaac)" );
   puts("  -r, --rounds=NUM        Number of times to wipe the device using the selected method (default: 1)" );
   puts("      --noblank           Do not blank disk after wipe (default is to complete a final blank pass)" );
+  puts("      --nowait            Do not wait for a key before exiting (default is to wait)" );
+  puts("      --nogui             Do not show the GUI interface. Automatically invokes the nowait option" );
+  puts("                          Must be used with --autonuke option");
   puts("");
   exit( EXIT_SUCCESS );
 }
